@@ -27,13 +27,6 @@ pd.set_option('display.max_rows', None, 'display.max_columns', None)
 pd.set_option('expand_frame_repr', False)
 pd.set_option('display.width', None)
 
-try:
-    os.mkdir('/noted')
-    os.mkdir('/noted/logs')
-    os.mkdir('/noted/config')
-    os.mkdir('/noted/query')
-    os.mkdir('/noted/transfers')
-except (KeyError, ValueError): logging.info('Building folders of the project.')
 app_timestamp = str(time.time()).split('.')[0]
 class_transfer_broker_ = TransferBroker()
 
